# OneNeuronPerceptron_pypi
OneNeuronPerceptron_pypi


# Reference
[Python package reference file](https://packaging.python.org/tutorials/packaging-projects/)
[Github doc for Github Actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)